==> ejc-businessplan-impl-3.0.0-20220321.111257-20-sources.jar: com/ejianc/business/change/bean/ChangesubpackagedetaillEntity.java <==
package com.ejianc.business.change.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包管理策划变更子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_change_businessplan_subpackagedetail")
public class ChangesubpackagedetaillEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 变更主表id
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="manager_content")
    private java.lang.String managerContent; // 管理内容
    @TableField(value="manager_aim")
    private java.lang.String managerAim; // 管理目标
    @TableField(value="manager_measures")
    private java.lang.String managerMeasures; // 管理措施
    @TableField(value="person_liable")
    private java.lang.String personLiable; // 责任人
    @TableField(value="plan_complete_time")
    private java.util.Date planCompleteTime; // 计划完成时间
    @TableField(value="implementation_effect")
    private java.lang.String implementationEffect; // 实施效果
    
    
    

    /**
     * 变更主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 变更主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 管理内容
     */
    public java.lang.String getManagerContent() {
        return managerContent;
    }

    /**
     * 管理内容
     */
    public void setManagerContent(java.lang.String managerContent) {
        this.managerContent = managerContent;
    }
    /**
     * 管理目标
     */
    public java.lang.String getManagerAim() {
        return managerAim;
    }

    /**
     * 管理目标
     */
    public void setManagerAim(java.lang.String managerAim) {
        this.managerAim = managerAim;
    }
    /**
     * 管理措施
     */
    public java.lang.String getManagerMeasures() {
        return managerMeasures;
    }

    /**
     * 管理措施
     */
    public void setManagerMeasures(java.lang.String managerMeasures) {
        this.managerMeasures = managerMeasures;
    }
    /**
     * 责任人
     */
    public java.lang.String getPersonLiable() {
        return personLiable;
    }

    /**
     * 责任人
     */
    public void setPersonLiable(java.lang.String personLiable) {
        this.personLiable = personLiable;
    }
    /**
     * 计划完成时间
     */
    public java.util.Date getPlanCompleteTime() {
        return planCompleteTime;
    }

    /**
     * 计划完成时间
     */
    public void setPlanCompleteTime(java.util.Date planCompleteTime) {
        this.planCompleteTime = planCompleteTime;
    }
    /**
     * 实施效果
     */
    public java.lang.String getImplementationEffect() {
        return implementationEffect;
    }

    /**
     * 实施效果
     */
    public void setImplementationEffect(java.lang.String implementationEffect) {
        this.implementationEffect = implementationEffect;
    }
    
}

==> ejc-businessplan-impl-3.0.0-20251021.083829-228-sources.jar: com/ejianc/business/change/bean/ChangesubpackagedetaillEntity.java <==
package com.ejianc.business.change.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包管理策划变更子表
 *
 * @author generator
 *
 */
 @TableName("ejc_change_businessplan_subpackagedetail")
public class ChangesubpackagedetaillEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="mid")
    private java.lang.Long mid; // 变更主表id
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="manager_content")
    private java.lang.String managerContent; // 管理内容
    @TableField(value="manager_aim")
    private java.lang.String managerAim; // 管理目标
    @TableField(value="manager_measures")
    private java.lang.String managerMeasures; // 管理措施
    @TableField(value="person_liable")
    private java.lang.String personLiable; // 责任人
    @TableField(value="plan_complete_time")
    private java.lang.String planCompleteTime; // 计划完成时间
    @TableField(value="implementation_effect")
    private java.lang.String implementationEffect; // 实施效果




    /**
     * 变更主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 变更主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 管理内容
     */
    public java.lang.String getManagerContent() {
        return managerContent;
    }

    /**
     * 管理内容
     */
    public void setManagerContent(java.lang.String managerContent) {
        this.managerContent = managerContent;
    }
    /**
     * 管理目标
     */
    public java.lang.String getManagerAim() {
        return managerAim;
    }

    /**
     * 管理目标
     */
    public void setManagerAim(java.lang.String managerAim) {
        this.managerAim = managerAim;
    }
    /**
     * 管理措施
     */
    public java.lang.String getManagerMeasures() {
        return managerMeasures;
    }

    /**
     * 管理措施
     */
    public void setManagerMeasures(java.lang.String managerMeasures) {
        this.managerMeasures = managerMeasures;
    }
    /**
     * 责任人
     */
    public java.lang.String getPersonLiable() {
        return personLiable;
    }

    /**
     * 责任人
     */
    public void setPersonLiable(java.lang.String personLiable) {
        this.personLiable = personLiable;
    }

    public String getPlanCompleteTime() {
        return planCompleteTime;
    }

    public void setPlanCompleteTime(String planCompleteTime) {
        this.planCompleteTime = planCompleteTime;
    }

    /**
     * 实施效果
     */
    public java.lang.String getImplementationEffect() {
        return implementationEffect;
    }

    /**
     * 实施效果
     */
    public void setImplementationEffect(java.lang.String implementationEffect) {
        this.implementationEffect = implementationEffect;
    }

}
